/*
 * libjingle
 * Copyright 2012 Google Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef TALK_MEDIA_BASE_FAKECAPTUREMANAGER_H_
#define TALK_MEDIA_BASE_FAKECAPTUREMANAGER_H_

#include "talk/media/base/capturemanager.h"

namespace cricket {

class FakeCaptureManager : public CaptureManager {
 public:
  FakeCaptureManager() {}
  ~FakeCaptureManager() {}

  virtual bool StartVideoCapture(VideoCapturer* video_capturer,
                                 const VideoFormat& desired_format) {
    if (!video_capturer) {
      return false;
    }
    video_capturer->Start(desired_format);
    return true;
  }
  virtual bool StopVideoCapture(VideoCapturer* video_capturer,
                                const VideoFormat& format) {
    if (!video_capturer) {
      return false;
    }
    video_capturer->Stop();
    return true;
  }
  virtual bool RestartVideoCapture(VideoCapturer* video_capturer,
                                   const VideoFormat& previous_format,
                                   const VideoFormat& desired_format,
                                   RestartOptions options) {
    if (!video_capturer) {
      return false;
    }
    return video_capturer->Restart(desired_format);
  }
  virtual bool AddVideoRenderer(VideoCapturer* video_capturer,
                                VideoRenderer* video_renderer) {
    return true;
  }
  virtual bool RemoveVideoRenderer(VideoCapturer* video_capturer,
                                   VideoRenderer* video_renderer) {
    return true;
  }
  virtual bool AddVideoProcessor(VideoCapturer* video_capturer,
                                 VideoProcessor* video_processor) {
    return true;
  }
  virtual bool RemoveVideoProcessor(VideoCapturer* video_capturer,
                                    VideoProcessor* video_processor) {
    return true;
  }
};

}  // namespace cricket

#endif  // TALK_MEDIA_BASE_FAKECAPTUREMANAGER_H_
